==> members-facade-1.0.2-20190109.061448-2-sources.jar: com/bizvane/members/facade/service/card/ApiUpdateMemberPhoneServiceAbstract.java <==
package com.bizvane.members.facade.service.card;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.service.card.request.UpdateMemberPhoneRequestModel;
import com.bizvane.members.facade.service.card.response.UpdateMemberPhoneResponseModel;
import com.bizvane.utils.enumutils.SysResponseEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/24.
 */
@Slf4j
public abstract class ApiUpdateMemberPhoneServiceAbstract {

    public abstract void validationData(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    public abstract UpdateMemberPhoneResponseModel syncSendPhoneToOffline(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    public abstract UpdateMemberPhoneResponseModel updateOnlineMemberPhone(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    @Transactional
    protected UpdateMemberPhoneResponseModel updatePhone(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel){
        //验证数据有效性
        this.validationData(updateMemberPhoneRequestModel);

        UpdateMemberPhoneResponseModel updateMemberPhoneResponseModel = null;

        //更新线上手机号
        try{
            updateMemberPhoneResponseModel = this.updateOnlineMemberPhone(updateMemberPhoneRequestModel);
        }catch(MemberException me){
            log.error(me.getMessage());
            me.getStackTrace();
            updateMemberPhoneResponseModel = new UpdateMemberPhoneResponseModel();
            updateMemberPhoneResponseModel.setCode(SysResponseEnum.FAILED.getCode());
            updateMemberPhoneResponseModel.setMessage("修改失败");
        }
        //如果线上成功更新线下手机号
        if(updateMemberPhoneResponseModel.getCode() == SysResponseEnum.SUCCESS.getCode()){
            updateMemberPhoneResponseModel = this.syncSendPhoneToOffline(updateMemberPhoneRequestModel);
        }
        return updateMemberPhoneResponseModel;
    }
}

==> members-facade-2.0.0-20191216.071819-179-sources.jar: com/bizvane/members/facade/service/card/ApiUpdateMemberPhoneServiceAbstract.java <==
package com.bizvane.members.facade.service.card;

import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.service.card.request.UpdateMemberPhoneRequestModel;
import com.bizvane.members.facade.service.card.response.UpdateMemberPhoneResponseModel;
import com.bizvane.utils.enumutils.SysResponseEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/24.
 */
@Slf4j
public abstract class ApiUpdateMemberPhoneServiceAbstract {

    public abstract void validationData(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    public abstract UpdateMemberPhoneResponseModel syncSendPhoneToOffline(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    public abstract UpdateMemberPhoneResponseModel updateOnlineMemberPhone(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel);

    @Transactional
    public UpdateMemberPhoneResponseModel updatePhone(UpdateMemberPhoneRequestModel updateMemberPhoneRequestModel){
        //验证数据有效性
        this.validationData(updateMemberPhoneRequestModel);

        UpdateMemberPhoneResponseModel updateMemberPhoneResponseModel = null;

        //更新线上手机号
        try{
            updateMemberPhoneResponseModel = this.updateOnlineMemberPhone(updateMemberPhoneRequestModel);
        }catch(MemberException me){
            log.error(me.getMessage());
            me.getStackTrace();
            updateMemberPhoneResponseModel = new UpdateMemberPhoneResponseModel();
            updateMemberPhoneResponseModel.setCode(SysResponseEnum.FAILED.getCode());
            updateMemberPhoneResponseModel.setMessage("修改失败");
        }
        //如果线上成功更新线下手机号
        if(updateMemberPhoneResponseModel.getCode() == SysResponseEnum.SUCCESS.getCode()){
            updateMemberPhoneResponseModel = this.syncSendPhoneToOffline(updateMemberPhoneRequestModel);
        }
        return updateMemberPhoneResponseModel;
    }
}
